';
diff --git a/doc/source/admin/conda_faq.rst b/doc/source/admin/conda_faq.rst
index 5ecefc9767d..5e51b10dce4 100644
--- a/doc/source/admin/conda_faq.rst
+++ b/doc/source/admin/conda_faq.rst
@@ -50,13 +50,17 @@ Below we answer some common questions (collected by Lance Parsons):
Galaxy's dependency job resolution is managed via
``dependency_resolvers_conf.xml`` configuration file. Most Galaxy administrators
-have not set up a dependency resolvers configuration file, which means they are
-using Galaxy's default ( ``dependency_resolvers_conf.xml.sample`` ). With
-release 16.04, Galaxy has enabled Conda dependency resolution by default when
+should be using Galaxy's default dependency resolvers configuration file
+( ``dependency_resolvers_conf.xml.sample`` ). With
+release 16.04, Galaxy has enabled Conda dependency resolution by default when
Conda was already installed on the system. Having Conda enabled in
-``dependency_resolvers_conf.xml`` means that Galaxy will look for job
+``dependency_resolvers_conf.xml`` means that Galaxy can look for job
dependencies using the Conda system when it attempts to run tools.
+Note that the order of resolvers in the file matters and the ````
+entry should remain first. This means that tools that have specified Tool Shed packages
+as their dependencies will work without a change.
+
The most common configuration settings related to Conda are listed in Table 1.
See `galaxy.ini.sample`_ for the complete list.
@@ -101,7 +105,7 @@ See `galaxy.ini.sample`_ for the complete list.
2. How do Conda dependencies work? Where do things get installed?
*********************************************************************************
-In contrast to the old dependency system, which was used exclusively by Galaxy,
+In contrast to the TS dependency system, which was used exclusively by Galaxy,
Conda is a pre-existing, independent project. With Conda, it is possible for an
admin to install and manage packages without touching Galaxy at all. Galaxy can
handle these dependencies for you, but admins are not required to use Galaxy for
@@ -170,19 +174,28 @@ systems newer than 2007.
This depends on your ``galaxy.ini`` setting. Starting with release 16.07, Galaxy
can automatically install the Conda package manager for you if you have enabled
``conda_auto_init``. Galaxy can then install Trinity along with its dependencies
-using one of the methods listed in question 2 above. Further, if
-``conda_auto_install`` is enabled, Galaxy will install Trinity via Conda only
-when a Trinity job is launched and Trinity is not yet installed.
+using one of the methods listed in question 2 above. In particular, if
+``conda_auto_install`` is True and Trinity is not installed yet, Galaxy will try
+to install it via Conda when a Trinity job is launched.
With release 16.07 you can see which dependencies are being used
in the “Manage installed tools” section of the Admin panel and you can select
whether or not to install Conda packages or Tool Shed package recipes when you
install new tools there, even if ``conda_auto_install`` is disabled.
-More improvements to the UI will be coming in future releases. To see if Galaxy
-has created a Trinity environment for you have a look at folder under
+During a tool installation, the Galaxy admin has control over which systems will be used to
+install the tool requirements. The default settings will trigger installation
+of both TS and Conda packages (if Conda is present), thus depending on the
+dependency resolvers configuration with regards to what will actually be used during
+the tool execution.
+
+To check if Galaxy has created a Trinity environment, have a look at folders under
``/_conda/envs/``(or ``/envs`` if you have changed `conda_prefix` in your galaxy.ini file).
+We recommend to use Conda on a tool-per-tool basis, by unchecking the checkbox
+for TS dependencies during the tool installation, and for tools where there
+are no available TS dependencies.
+
5. Can I mix traditional Galaxy packages and Conda packages?
*********************************************************************************
@@ -198,7 +211,8 @@ The order in which resolvers are tried is listed in the
- Packages manually installed by administrators
- Conda packages
-The first system that satisfies a requirement will be used.
+The first system that satisfies a requirement will be used. See
+`resolver docs`_ for detailed documentation.
6. How do I know what system is being used by a given tool?
@@ -206,10 +220,7 @@ The first system that satisfies a requirement will be used.
The Galaxy log will show which dependency resolution system is used
to satisfy each tool dependency and you can specify priorities using the
-``dependency_resolution_conf.xml`` file. If you put Conda on
-top, Galaxy will first try to use Conda to resolve a tool dependency;
-if this does not work, the following dependency resolver is used, as
-listed. See `resolver docs`_ for detailed documentation. Starting from Galaxy
+``dependency_resolvers_conf.xml`` file (see question 5 above). Starting from Galaxy
release 16.07, you can see which dependency will be used (“resolved”) in the
Admin panel.
diff --git a/lib/galaxy/tools/deps/__init__.py b/lib/galaxy/tools/deps/__init__.py
index 7ba346c10da..763732e4dc7 100644
--- a/lib/galaxy/tools/deps/__init__.py
+++ b/lib/galaxy/tools/deps/__init__.py
@@ -24,6 +24,7 @@ EXTRA_CONFIG_KWDS = {
'conda_ensure_channels': 'r,bioconda,iuc',
'conda_auto_install': False,
'conda_auto_init': False,
+ 'conda_copy_dependencies': False,
}
CONFIG_VAL_NOT_FOUND = object()
diff --git a/static/maps/mvc/ui/ui-modal.js.map b/static/maps/mvc/ui/ui-modal.js.map
index a9b5098d1f4..bc40aaccddf 100644
--- a/static/maps/mvc/ui/ui-modal.js.map
+++ b/static/maps/mvc/ui/ui-modal.js.map
@@ -1 +1 @@
-{"version":3,"file":"ui-modal.js","sources":["../../../src/mvc/ui/ui-modal.js"],"names":["define","View","Backbone","extend","optionsDefault","container","title","cls","body","backdrop","height","width","closing_events","closing_callback","title_separator","buttonList","initialize","options","this","setElement","_template","_","defaults","$","prepend","el","$header","$dialog","$body","$footer","$backdrop","$buttons","render","show","visible","$el","fadeIn","self","document","on","e","keyCode","hide","canceled","fadeOut","off","removeClass","addClass","find","html","empty","buttons","counter","each","name","callback","$button","attr","text","click","append","removeAttr","css","window","getButton","enableButton","prop","disableButton","showButton","hideButton","scrollTop"],"mappings":"AAAAA,UAAW,WACX,GAAIC,GAAOC,SAASD,KAAKE,QAErBC,gBACIC,UAAmB,OACnBC,MAAmB,WACnBC,IAAmB,WACnBC,KAAmB,GACnBC,UAAmB,EACnBC,OAAmB,KACnBC,MAAmB,KACnBC,gBAAmB,EACnBC,iBAAmB,KACnBC,iBAAmB,GAIvBC,cAGAC,WAAY,SAAUC,GAClBC,KAAKC,WAAYD,KAAKE,aACtBF,KAAKD,QAAUI,EAAEC,SAAUL,MAAeC,KAAKd,gBAC/CmB,EAAGL,KAAKD,QAAQZ,WAAYmB,QAASN,KAAKO,IAG1CP,KAAKQ,QAAaR,KAAKK,EAAG,iBAC1BL,KAAKS,QAAaT,KAAKK,EAAG,iBAC1BL,KAAKU,MAAaV,KAAKK,EAAG,eAC1BL,KAAKW,QAAaX,KAAKK,EAAG,iBAC1BL,KAAKY,UAAaZ,KAAKK,EAAG,mBAC1BL,KAAKa,SAAab,KAAKK,EAAG,YAG1BN,GAAWC,KAAKc,UAMpBC,KAAM,SAAUhB,GAKZ,GAJKA,IACDC,KAAKD,QAAUI,EAAEC,SAAUL,EAASC,KAAKd,gBACzCc,KAAKc,WAEHd,KAAKgB,UACPhB,KAAKgB,SAAU,EACfhB,KAAKiB,IAAIC,OAAQ,QACZlB,KAAKD,QAAQL,gBAAiB,CAC/B,GAAIyB,GAAOnB,IACXK,GAAGe,UAAWC,GAAI,iBAAkB,SAAUC,GAAmB,IAAbA,EAAEC,SAAiBJ,EAAKK,MAAM,KAClFxB,KAAKY,UAAUS,GAAI,QAAS,WAAaF,EAAKK,MAAM,OAQhEA,KAAM,SAAUC,GACZzB,KAAKgB,SAAU,EACfhB,KAAKiB,IAAIS,QAAS,QAClB1B,KAAKD,QAAQJ,kBAAoBK,KAAKD,QAAQJ,iBAAkB8B,GAChEpB,EAAGe,UAAWO,IAAK,kBACnB3B,KAAKY,UAAUe,IAAK,UAMxBb,OAAQ,WACJ,GAAIK,GAAOnB,IAeX,IAdyB,YAArBA,KAAKD,QAAQT,OACbU,KAAKD,QAAQT,KAAOe,EAAI,yHAM5BL,KAAKiB,IAAIW,cAAcC,SAAU,SAAUA,SAAU7B,KAAKD,QAAQV,KAClEW,KAAKQ,QAAQsB,KAAM,UAAWC,KAAM/B,KAAKD,QAAQX,OACjDY,KAAKU,MAAMqB,KAAM/B,KAAKD,QAAQT,MAG9BU,KAAKa,SAASmB,QACdhC,KAAKH,cACAG,KAAKD,QAAQkC,QAAU,CACxB,GAAIC,GAAU,CACd7B,GAAE8B,KAAMnC,KAAKD,QAAQkC,QAAS,SAAUG,EAAMC,GAC1C,GAAIC,GAAUjC,EAAG,aAAckC,KAAM,KAAM,UAAYL,KAAYM,KAAMJ,GAAOK,MAAOJ,EACvFlB,GAAKN,SAAS6B,OAAQJ,GAAUI,OAAQ,UACxCvB,EAAKtB,WAAYuC,GAASE,QAG9BtC,MAAKW,QAAQa,MAIjBxB,MAAKY,UAAWZ,KAAKD,QAAQR,UAAY,YAAc,eAAiB,MACxES,KAAKQ,SAAUR,KAAKD,QAAQH,iBAAmB,YAAc,eAAiB,gBAI9EI,KAAKU,MAAMiC,WAAY,SAClB3C,KAAKD,QAAQP,QACdQ,KAAKU,MAAMkC,IAAK,SAAU5C,KAAKD,QAAQP,QACvCQ,KAAKU,MAAMkC,IAAK,WAAY,WAE5B5C,KAAKU,MAAMkC,IAAK,aAAcvC,EAAGwC,QAASrD,SAAW,GAEpDQ,KAAKD,QAAQN,OACdO,KAAKS,QAAQmC,IAAK,QAAS5C,KAAKD,QAAQN,QAQhDqD,UAAW,SAAUV,GACjB,MAAOpC,MAAKH,WAAYuC,IAO5BW,aAAc,SAAUX,GACpBpC,KAAK8C,UAAWV,GAAOY,KAAM,YAAY,IAO7CC,cAAe,SAAUb,GACrBpC,KAAK8C,UAAWV,GAAOY,KAAM,YAAY,IAO7CE,WAAY,SAAUd,GAClBpC,KAAK8C,UAAWV,GAAOrB,QAO3BoC,WAAY,SAAUf,GAClBpC,KAAK8C,UAAWV,GAAOZ,QAM3B4B,UAAW,WACP,MAAOpD,MAAKU,MAAM0C,aAMtBlD,UAAW,WACP,MAAQ,sQAiBhB,QACInB,KAAOA"}
\ No newline at end of file
+{"version":3,"file":"ui-modal.js","sources":["../../../src/mvc/ui/ui-modal.js"],"names":["define","View","Backbone","extend","className","optionsDefault","container","title","cls","body","backdrop","height","width","closing_events","closing_callback","title_separator","buttonList","initialize","options","this","_","defaults","$","prepend","el","render","show","visible","$el","fadeIn","self","document","on","e","keyCode","hide","$backdrop","canceled","fadeOut","off","html","_template","$header","$dialog","$body","$footer","$buttons","removeClass","addClass","find","empty","buttons","counter","each","name","callback","$button","attr","text","click","append","removeAttr","css","window","getButton","enableButton","prop","disableButton","showButton","hideButton","scrollTop"],"mappings":"AAAAA,UAAW,WACX,GAAIC,GAAOC,SAASD,KAAKE,QAErBC,UAAW,WAGXC,gBACIC,UAAmB,OACnBC,MAAmB,WACnBC,IAAmB,WACnBC,KAAmB,GACnBC,UAAmB,EACnBC,OAAmB,KACnBC,MAAmB,KACnBC,gBAAmB,EACnBC,iBAAmB,KACnBC,iBAAmB,GAIvBC,cAGAC,WAAY,SAAUC,GAClBC,KAAKD,QAAUE,EAAEC,SAAUH,MAAeC,KAAKd,gBAC/CiB,EAAGH,KAAKD,QAAQZ,WAAYiB,QAASJ,KAAKK,IAE1CN,GAAWC,KAAKM,UAMpBC,KAAM,SAAUR,GAKZ,GAJKA,IACDC,KAAKD,QAAUE,EAAEC,SAAUH,EAASC,KAAKd,gBACzCc,KAAKM,WAEHN,KAAKQ,UACPR,KAAKQ,SAAU,EACfR,KAAKS,IAAIC,OAAQ,QACZV,KAAKD,QAAQL,gBAAiB,CAC/B,GAAIiB,GAAOX,IACXG,GAAGS,UAAWC,GAAI,iBAAkB,SAAUC,GAAmB,IAAbA,EAAEC,SAAiBJ,EAAKK,MAAM,KAClFhB,KAAKiB,UAAUJ,GAAI,QAAS,WAAaF,EAAKK,MAAM,OAQhEA,KAAM,SAAUE,GACZlB,KAAKQ,SAAU,EACfR,KAAKS,IAAIU,QAAS,QAClBnB,KAAKD,QAAQJ,kBAAoBK,KAAKD,QAAQJ,iBAAkBuB,GAChEf,EAAGS,UAAWQ,IAAK,kBACnBpB,KAAKiB,UAAUG,IAAK,UAMxBd,OAAQ,WACJ,GAAIK,GAAOX,IAyBX,IAxBAA,KAAKS,IAAIY,KAAMrB,KAAKsB,aAGpBtB,KAAKuB,QAAavB,KAAKG,EAAG,iBAC1BH,KAAKwB,QAAaxB,KAAKG,EAAG,iBAC1BH,KAAKyB,MAAazB,KAAKG,EAAG,eAC1BH,KAAK0B,QAAa1B,KAAKG,EAAG,iBAC1BH,KAAKiB,UAAajB,KAAKG,EAAG,mBAC1BH,KAAK2B,SAAa3B,KAAKG,EAAG,YAED,YAArBH,KAAKD,QAAQT,OACbU,KAAKD,QAAQT,KAAOa,EAAI,yHAM5BH,KAAKS,IAAImB,cAAcC,SAAU,SAAUA,SAAU7B,KAAKD,QAAQV,KAClEW,KAAKuB,QAAQO,KAAM,UAAWT,KAAMrB,KAAKD,QAAQX,OACjDY,KAAKyB,MAAMJ,KAAMrB,KAAKD,QAAQT,MAG9BU,KAAK2B,SAASI,QACd/B,KAAKH,cACAG,KAAKD,QAAQiC,QAAU,CACxB,GAAIC,GAAU,CACd9B,GAAE+B,KAAMlC,KAAKD,QAAQiC,QAAS,SAAUG,EAAMC,GAC1C,GAAIC,GAAUlC,EAAG,aAAcmC,KAAM,KAAM,UAAYL,KAAYM,KAAMJ,GAAOK,MAAOJ,EACvFzB,GAAKgB,SAASc,OAAQJ,GAAUI,OAAQ,UACxC9B,EAAKd,WAAYsC,GAASE,QAG9BrC,MAAK0B,QAAQV,MAIjBhB,MAAKiB,UAAWjB,KAAKD,QAAQR,UAAY,YAAc,eAAiB,MACxES,KAAKuB,SAAUvB,KAAKD,QAAQH,iBAAmB,YAAc,eAAiB,gBAI9EI,KAAKyB,MAAMiB,WAAY,SAClB1C,KAAKD,QAAQP,QACdQ,KAAKyB,MAAMkB,IAAK,SAAU3C,KAAKD,QAAQP,QACvCQ,KAAKyB,MAAMkB,IAAK,WAAY,WAE5B3C,KAAKyB,MAAMkB,IAAK,aAAcxC,EAAGyC,QAASpD,SAAW,GAEpDQ,KAAKD,QAAQN,OACdO,KAAKwB,QAAQmB,IAAK,QAAS3C,KAAKD,QAAQN,QAQhDoD,UAAW,SAAUV,GACjB,MAAOnC,MAAKH,WAAYsC,IAO5BW,aAAc,SAAUX,GACpBnC,KAAK6C,UAAWV,GAAOY,KAAM,YAAY,IAO7CC,cAAe,SAAUb,GACrBnC,KAAK6C,UAAWV,GAAOY,KAAM,YAAY,IAO7CE,WAAY,SAAUd,GAClBnC,KAAK6C,UAAWV,GAAO5B,QAO3B2C,WAAY,SAAUf,GAClBnC,KAAK6C,UAAWV,GAAOnB,QAM3BmC,UAAW,WACP,MAAOnD,MAAKyB,MAAM0B,aAMtB7B,UAAW,WACP,MAAQ,0OAehB,QACIxC,KAAOA"}
\ No newline at end of file
diff --git a/static/scripts/bundled/libs.bundled.js b/static/scripts/bundled/libs.bundled.js
index 4c845a5f10b..1ffb0386cd0 100644
--- a/static/scripts/bundled/libs.bundled.js
+++ b/static/scripts/bundled/libs.bundled.js
@@ -1,4 +1,4 @@
-!function(t){function e(i){if(n[i])return n[i].exports;var r=n[i]={exports:{},id:i,loaded:!1};return t[i].call(r.exports,r,r.exports,e),r.loaded=!0,r.exports}var i=window.webpackJsonp;window.webpackJsonp=function(s,o){for(var a,l,u=0,c=[];u0&&e-1 in t}function a(t,e,i){if(vt.isFunction(e))return vt.grep(t,function(t,n){return!!e.call(t,n,t)!==i});if(e.nodeType)return vt.grep(t,function(t){return t===e!==i});if("string"==typeof e){if(Et.test(e))return vt.filter(e,t,i);e=vt.filter(e,t)}return vt.grep(t,function(t){return vt.inArray(t,e)>-1!==i})}function l(t,e){do t=t[e];while(t&&1!==t.nodeType);return t}function u(t){var e={};return vt.each(t.match(Dt)||[],function(t,i){e[i]=!0}),e}function c(){at.addEventListener?(at.removeEventListener("DOMContentLoaded",h),i.removeEventListener("load",h)):(at.detachEvent("onreadystatechange",h),i.detachEvent("onload",h))}function h(){(at.addEventListener||"load"===i.event.type||"complete"===at.readyState)&&(c(),vt.ready())}function d(t,e,i){if(void 0===i&&1===t.nodeType){var n="data-"+e.replace(jt,"-$1").toLowerCase();if(i=t.getAttribute(n),"string"==typeof i){try{i="true"===i?!0:"false"===i?!1:"null"===i?null:+i+""===i?+i:It.test(i)?vt.parseJSON(i):i}catch(r){}vt.data(t,e,i)}else i=void 0}return i}function p(t){var e;for(e in t)if(("data"!==e||!vt.isEmptyObject(t[e]))&&"toJSON"!==e)return!1;return!0}function f(t,e,i,n){if(Ht(t)){var r,s,o=vt.expando,a=t.nodeType,l=a?vt.cache:t,u=a?t[o]:t[o]&&o;if(u&&l[u]&&(n||l[u].data)||void 0!==i||"string"!=typeof e)return u||(u=a?t[o]=ot.pop()||vt.guid++:o),l[u]||(l[u]=a?{}:{toJSON:vt.noop}),("object"==typeof e||"function"==typeof e)&&(n?l[u]=vt.extend(l[u],e):l[u].data=vt.extend(l[u].data,e)),s=l[u],n||(s.data||(s.data={}),s=s.data),void 0!==i&&(s[vt.camelCase(e)]=i),"string"==typeof e?(r=s[e],null==r&&(r=s[vt.camelCase(e)])):r=s,r}}function g(t,e,i){if(Ht(t)){var n,r,s=t.nodeType,o=s?vt.cache:t,a=s?t[vt.expando]:vt.expando;if(o[a]){if(e&&(n=i?o[a]:o[a].data)){vt.isArray(e)?e=e.concat(vt.map(e,vt.camelCase)):e in n?e=[e]:(e=vt.camelCase(e),e=e in n?[e]:e.split(" ")),r=e.length;for(;r--;)delete n[e[r]];if(i?!p(n):!vt.isEmptyObject(n))return}(i||(delete o[a].data,p(o[a])))&&(s?vt.cleanData([t],!0):gt.deleteExpando||o!=o.window?delete o[a]:o[a]=void 0)}}}function m(t,e,i,n){var r,s=1,o=20,a=n?function(){return n.cur()}:function(){return vt.css(t,e,"")},l=a(),u=i&&i[3]||(vt.cssNumber[e]?"":"px"),c=(vt.cssNumber[e]||"px"!==u&&+l)&&Ft.exec(vt.css(t,e));if(c&&c[3]!==u){u=u||c[3],i=i||[],c=+l||1;do s=s||".5",c/=s,vt.style(t,e,c+u);while(s!==(s=a()/l)&&1!==s&&--o)}return i&&(c=+c||+l||0,r=i[1]?c+(i[1]+1)*i[2]:+i[2],n&&(n.unit=u,n.start=c,n.end=r)),r}function v(t){var e=Xt.split("|"),i=t.createDocumentFragment();if(i.createElement)for(;e.length;)i.createElement(e.pop());return i}function y(t,e){var i,n,r=0,s="undefined"!=typeof t.getElementsByTagName?t.getElementsByTagName(e||"*"):"undefined"!=typeof t.querySelectorAll?t.querySelectorAll(e||"*"):void 0;if(!s)for(s=[],i=t.childNodes||t;null!=(n=i[r]);r++)!e||vt.nodeName(n,e)?s.push(n):vt.merge(s,y(n,e));return void 0===e||e&&vt.nodeName(t,e)?vt.merge([t],s):s}function b(t,e){for(var i,n=0;null!=(i=t[n]);n++)vt._data(i,"globalEval",!e||vt._data(e[n],"globalEval"))}function _(t){Bt.test(t.type)&&(t.defaultChecked=t.checked)}function w(t,e,i,n,r){for(var s,o,a,l,u,c,h,d=t.length,p=v(e),f=[],g=0;d>g;g++)if(o=t[g],o||0===o)if("object"===vt.type(o))vt.merge(f,o.nodeType?[o]:o);else if(Yt.test(o)){for(l=l||p.appendChild(e.createElement("div")),u=(Ut.exec(o)||["",""])[1].toLowerCase(),h=Jt[u]||Jt._default,l.innerHTML=h[1]+vt.htmlPrefilter(o)+h[2],s=h[0];s--;)l=l.lastChild;if(!gt.leadingWhitespace&&Gt.test(o)&&f.push(e.createTextNode(Gt.exec(o)[0])),!gt.tbody)for(o="table"!==u||Qt.test(o)?"
"!==h[1]||Qt.test(o)?0:l:l.firstChild,s=o&&o.childNodes.length;s--;)vt.nodeName(c=o.childNodes[s],"tbody")&&!c.childNodes.length&&o.removeChild(c);for(vt.merge(f,l.childNodes),l.textContent="";l.firstChild;)l.removeChild(l.firstChild);l=p.lastChild}else f.push(e.createTextNode(o));for(l&&p.removeChild(l),gt.appendChecked||vt.grep(y(f,"input"),_),g=0;o=f[g++];)if(n&&vt.inArray(o,n)>-1)r&&r.push(o);else if(a=vt.contains(o.ownerDocument,o),l=y(p.appendChild(o),"script"),a&&b(l),i)for(s=0;o=l[s++];)Vt.test(o.type||"")&&i.push(o);return l=null,p}function x(){return!0}function C(){return!1}function S(){try{return at.activeElement}catch(t){}}function k(t,e,i,n,r,s){var o,a;if("object"==typeof e){"string"!=typeof i&&(n=n||i,i=void 0);for(a in e)k(t,a,i,n,e[a],s);return t}if(null==n&&null==r?(r=i,n=i=void 0):null==r&&("string"==typeof i?(r=n,n=void 0):(r=n,n=i,i=void 0)),r===!1)r=C;else if(!r)return t;return 1===s&&(o=r,r=function(t){return vt().off(t),o.apply(this,arguments)},r.guid=o.guid||(o.guid=vt.guid++)),t.each(function(){vt.event.add(this,e,r,n,i)})}function T(t,e){return vt.nodeName(t,"table")&&vt.nodeName(11!==e.nodeType?e:e.firstChild,"tr")?t.getElementsByTagName("tbody")[0]||t.appendChild(t.ownerDocument.createElement("tbody")):t}function E(t){return t.type=(null!==vt.find.attr(t,"type"))+"/"+t.type,t}function A(t){var e=le.exec(t.type);return e?t.type=e[1]:t.removeAttribute("type"),t}function N(t,e){if(1===e.nodeType&&vt.hasData(t)){var i,n,r,s=vt._data(t),o=vt._data(e,s),a=s.events;if(a){delete o.handle,o.events={};for(i in a)for(n=0,r=a[i].length;r>n;n++)vt.event.add(e,i,a[i][n])}o.data&&(o.data=vt.extend({},o.data))}}function O(t,e){var i,n,r;if(1===e.nodeType){if(i=e.nodeName.toLowerCase(),!gt.noCloneEvent&&e[vt.expando]){r=vt._data(e);for(n in r.events)vt.removeEvent(e,n,r.handle);e.removeAttribute(vt.expando)}"script"===i&&e.text!==t.text?(E(e).text=t.text,A(e)):"object"===i?(e.parentNode&&(e.outerHTML=t.outerHTML),gt.html5Clone&&t.innerHTML&&!vt.trim(e.innerHTML)&&(e.innerHTML=t.innerHTML)):"input"===i&&Bt.test(t.type)?(e.defaultChecked=e.checked=t.checked,e.value!==t.value&&(e.value=t.value)):"option"===i?e.defaultSelected=e.selected=t.defaultSelected:("input"===i||"textarea"===i)&&(e.defaultValue=t.defaultValue)}}function M(t,e,i,n){e=ut.apply([],e);var r,s,o,a,l,u,c=0,h=t.length,d=h-1,p=e[0],f=vt.isFunction(p);if(f||h>1&&"string"==typeof p&&!gt.checkClone&&ae.test(p))return t.each(function(r){var s=t.eq(r);f&&(e[0]=p.call(this,r,s.html())),M(s,e,i,n)});if(h&&(u=w(e,t[0].ownerDocument,!1,t,n),r=u.firstChild,1===u.childNodes.length&&(u=r),r||n)){for(a=vt.map(y(u,"script"),E),o=a.length;h>c;c++)s=u,c!==d&&(s=vt.clone(s,!0,!0),o&&vt.merge(a,y(s,"script"))),i.call(t[c],s,c);if(o)for(l=a[a.length-1].ownerDocument,vt.map(a,A),c=0;o>c;c++)s=a[c],Vt.test(s.type||"")&&!vt._data(s,"globalEval")&&vt.contains(l,s)&&(s.src?vt._evalUrl&&vt._evalUrl(s.src):vt.globalEval((s.text||s.textContent||s.innerHTML||"").replace(ue,"")));u=r=null}return t}function P(t,e,i){for(var n,r=e?vt.filter(e,t):t,s=0;null!=(n=r[s]);s++)i||1!==n.nodeType||vt.cleanData(y(n)),n.parentNode&&(i&&vt.contains(n.ownerDocument,n)&&b(y(n,"script")),n.parentNode.removeChild(n));return t}function D(t,e){var i=vt(e.createElement(t)).appendTo(e.body),n=vt.css(i[0],"display");return i.detach(),n}function R(t){var e=at,i=pe[t];return i||(i=D(t,e),"none"!==i&&i||(de=(de||vt("")).appendTo(e.documentElement),e=(de[0].contentWindow||de[0].contentDocument).document,e.write(),e.close(),i=D(t,e),de.detach()),pe[t]=i),i}function L(t,e){return{get:function(){return t()?void delete this.get:(this.get=e).apply(this,arguments)}}}function H(t){if(t in Ae)return t;for(var e=t.charAt(0).toUpperCase()+t.slice(1),i=Ee.length;i--;)if(t=Ee[i]+e,t in Ae)return t}function I(t,e){for(var i,n,r,s=[],o=0,a=t.length;a>o;o++)n=t[o],n.style&&(s[o]=vt._data(n,"olddisplay"),i=n.style.display,e?(s[o]||"none"!==i||(n.style.display=""),""===n.style.display&&Wt(n)&&(s[o]=vt._data(n,"olddisplay",R(n.nodeName)))):(r=Wt(n),(i&&"none"!==i||!r)&&vt._data(n,"olddisplay",r?i:vt.css(n,"display"))));for(o=0;a>o;o++)n=t[o],n.style&&(e&&"none"!==n.style.display&&""!==n.style.display||(n.style.display=e?s[o]||"":"none"));return t}function j(t,e,i){var n=Se.exec(e);return n?Math.max(0,n[1]-(i||0))+(n[2]||"px"):e}function $(t,e,i,n,r){for(var s=i===(n?"border":"content")?4:"width"===e?1:0,o=0;4>s;s+=2)"margin"===i&&(o+=vt.css(t,i+qt[s],!0,r)),n?("content"===i&&(o-=vt.css(t,"padding"+qt[s],!0,r)),"margin"!==i&&(o-=vt.css(t,"border"+qt[s]+"Width",!0,r))):(o+=vt.css(t,"padding"+qt[s],!0,r),"padding"!==i&&(o+=vt.css(t,"border"+qt[s]+"Width",!0,r)));return o}function F(t,e,i){var n=!0,r="width"===e?t.offsetWidth:t.offsetHeight,s=ye(t),o=gt.boxSizing&&"border-box"===vt.css(t,"boxSizing",!1,s);if(0>=r||null==r){if(r=be(t,e,s),(0>r||null==r)&&(r=t.style[e]),ge.test(r))return r;n=o&&(gt.boxSizingReliable()||r===t.style[e]),r=parseFloat(r)||0}return r+$(t,e,i||(o?"border":"content"),n,s)+"px"}function q(t,e,i,n,r){return new q.prototype.init(t,e,i,n,r)}function W(){return i.setTimeout(function(){Ne=void 0}),Ne=vt.now()}function z(t,e){var i,n={height:t},r=0;for(e=e?1:0;4>r;r+=2-e)i=qt[r],n["margin"+i]=n["padding"+i]=t;return e&&(n.opacity=n.width=t),n}function B(t,e,i){for(var n,r=(G.tweeners[e]||[]).concat(G.tweeners["*"]),s=0,o=r.length;o>s;s++)if(n=r[s].call(i,e,t))return n}function U(t,e,i){var n,r,s,o,a,l,u,c,h=this,d={},p=t.style,f=t.nodeType&&Wt(t),g=vt._data(t,"fxshow");i.queue||(a=vt._queueHooks(t,"fx"),null==a.unqueued&&(a.unqueued=0,l=a.empty.fire,a.empty.fire=function(){a.unqueued||l()}),a.unqueued++,h.always(function(){h.always(function(){a.unqueued--,vt.queue(t,"fx").length||a.empty.fire()})})),1===t.nodeType&&("height"in e||"width"in e)&&(i.overflow=[p.overflow,p.overflowX,p.overflowY],u=vt.css(t,"display"),c="none"===u?vt._data(t,"olddisplay")||R(t.nodeName):u,"inline"===c&&"none"===vt.css(t,"float")&&(gt.inlineBlockNeedsLayout&&"inline"!==R(t.nodeName)?p.zoom=1:p.display="inline-block")),i.overflow&&(p.overflow="hidden",gt.shrinkWrapBlocks()||h.always(function(){p.overflow=i.overflow[0],p.overflowX=i.overflow[1],p.overflowY=i.overflow[2]}));for(n in e)if(r=e[n],Me.exec(r)){if(delete e[n],s=s||"toggle"===r,r===(f?"hide":"show")){if("show"!==r||!g||void 0===g[n])continue;f=!0}d[n]=g&&g[n]||vt.style(t,n)}else u=void 0;if(vt.isEmptyObject(d))"inline"===("none"===u?R(t.nodeName):u)&&(p.display=u);else{g?"hidden"in g&&(f=g.hidden):g=vt._data(t,"fxshow",{}),s&&(g.hidden=!f),f?vt(t).show():h.done(function(){vt(t).hide()}),h.done(function(){var e;vt._removeData(t,"fxshow");for(e in d)vt.style(t,e,d[e])});for(n in d)o=B(f?g[n]:0,n,h),n in g||(g[n]=o.start,f&&(o.end=o.start,o.start="width"===n||"height"===n?1:0))}}function V(t,e){var i,n,r,s,o;for(i in t)if(n=vt.camelCase(i),r=e[n],s=t[i],vt.isArray(s)&&(r=s[1],s=t[i]=s[0]),i!==n&&(t[n]=s,delete t[i]),o=vt.cssHooks[n],o&&"expand"in o){s=o.expand(s),delete t[n];for(i in s)i in t||(t[i]=s[i],e[i]=r)}else e[n]=r}function G(t,e,i){var n,r,s=0,o=G.prefilters.length,a=vt.Deferred().always(function(){delete l.elem}),l=function(){if(r)return!1;for(var e=Ne||W(),i=Math.max(0,u.startTime+u.duration-e),n=i/u.duration||0,s=1-n,o=0,l=u.tweens.length;l>o;o++)u.tweens[o].run(s);return a.notifyWith(t,[u,s,i]),1>s&&l?i:(a.resolveWith(t,[u]),!1)},u=a.promise({elem:t,props:vt.extend({},e),opts:vt.extend(!0,{specialEasing:{},easing:vt.easing._default},i),originalProperties:e,originalOptions:i,startTime:Ne||W(),duration:i.duration,tweens:[],createTween:function(e,i){var n=vt.Tween(t,u.opts,e,i,u.opts.specialEasing[e]||u.opts.easing);return u.tweens.push(n),n},stop:function(e){var i=0,n=e?u.tweens.length:0;if(r)return this;for(r=!0;n>i;i++)u.tweens[i].run(1);return e?(a.notifyWith(t,[u,1,0]),a.resolveWith(t,[u,e])):a.rejectWith(t,[u,e]),this}}),c=u.props;for(V(c,u.opts.specialEasing);o>s;s++)if(n=G.prefilters[s].call(u,t,c,u.opts))return vt.isFunction(n.stop)&&(vt._queueHooks(u.elem,u.opts.queue).stop=vt.proxy(n.stop,n)),n;return vt.map(c,B,u),vt.isFunction(u.opts.start)&&u.opts.start.call(t,u),vt.fx.timer(vt.extend(l,{elem:t,anim:u,queue:u.opts.queue})),u.progress(u.opts.progress).done(u.opts.done,u.opts.complete).fail(u.opts.fail).always(u.opts.always)}function X(t){return vt.attr(t,"class")||""}function J(t){return function(e,i){"string"!=typeof e&&(i=e,e="*");var n,r=0,s=e.toLowerCase().match(Dt)||[];if(vt.isFunction(i))for(;n=s[r++];)"+"===n.charAt(0)?(n=n.slice(1)||"*",(t[n]=t[n]||[]).unshift(i)):(t[n]=t[n]||[]).push(i)}}function Y(t,e,i,n){function r(a){var l;return s[a]=!0,vt.each(t[a]||[],function(t,a){var u=a(e,i,n);return"string"!=typeof u||o||s[u]?o?!(l=u):void 0:(e.dataTypes.unshift(u),r(u),!1)}),l}var s={},o=t===ii;return r(e.dataTypes[0])||!s["*"]&&r("*")}function Q(t,e){var i,n,r=vt.ajaxSettings.flatOptions||{};for(n in e)void 0!==e[n]&&((r[n]?t:i||(i={}))[n]=e[n]);return i&&vt.extend(!0,t,i),t}function K(t,e,i){for(var n,r,s,o,a=t.contents,l=t.dataTypes;"*"===l[0];)l.shift(),void 0===r&&(r=t.mimeType||e.getResponseHeader("Content-Type"));if(r)for(o in a)if(a[o]&&a[o].test(r)){l.unshift(o);break}if(l[0]in i)s=l[0];else{for(o in i){if(!l[0]||t.converters[o+" "+l[0]]){s=o;break}n||(n=o)}s=s||n}return s?(s!==l[0]&&l.unshift(s),i[s]):void 0}function Z(t,e,i,n){var r,s,o,a,l,u={},c=t.dataTypes.slice();if(c[1])for(o in t.converters)u[o.toLowerCase()]=t.converters[o];for(s=c.shift();s;)if(t.responseFields[s]&&(i[t.responseFields[s]]=e),!l&&n&&t.dataFilter&&(e=t.dataFilter(e,t.dataType)),l=s,s=c.shift())if("*"===s)s=l;else if("*"!==l&&l!==s){if(o=u[l+" "+s]||u["* "+s],!o)for(r in u)if(a=r.split(" "),a[1]===s&&(o=u[l+" "+a[0]]||u["* "+a[0]])){o===!0?o=u[r]:u[r]!==!0&&(s=a[0],c.unshift(a[1]));break}if(o!==!0)if(o&&t["throws"])e=o(e);else try{e=o(e)}catch(h){return{state:"parsererror",error:o?h:"No conversion from "+l+" to "+s}}}return{state:"success",data:e}}function tt(t){return t.style&&t.style.display||vt.css(t,"display")}function et(t){if(!vt.contains(t.ownerDocument||at,t))return!0;for(;t&&1===t.nodeType;){if("none"===tt(t)||"hidden"===t.type)return!0;t=t.parentNode}return!1}function it(t,e,i,n){var r;if(vt.isArray(e))vt.each(e,function(e,r){i||ai.test(t)?n(t,r):it(t+"["+("object"==typeof r&&null!=r?e:"")+"]",r,i,n)});else if(i||"object"!==vt.type(e))n(t,e);else for(r in e)it(t+"["+r+"]",e[r],i,n)}function nt(){try{return new i.XMLHttpRequest}catch(t){}}function rt(){try{return new i.ActiveXObject("Microsoft.XMLHTTP")}catch(t){}}function st(t){return vt.isWindow(t)?t:9===t.nodeType?t.defaultView||t.parentWindow:!1}var ot=[],at=i.document,lt=ot.slice,ut=ot.concat,ct=ot.push,ht=ot.indexOf,dt={},pt=dt.toString,ft=dt.hasOwnProperty,gt={},mt="1.12.4",vt=function(t,e){return new vt.fn.init(t,e)},yt=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,bt=/^-ms-/,_t=/-([\da-z])/gi,wt=function(t,e){return e.toUpperCase()};vt.fn=vt.prototype={jquery:mt,constructor:vt,selector:"",length:0,toArray:function(){return lt.call(this)},get:function(t){return null!=t?0>t?this[t+this.length]:this[t]:lt.call(this)},pushStack:function(t){var e=vt.merge(this.constructor(),t);return e.prevObject=this,e.context=this.context,e},each:function(t){return vt.each(this,t)},map:function(t){return this.pushStack(vt.map(this,function(e,i){return t.call(e,i,e)}))},slice:function(){return this.pushStack(lt.apply(this,arguments))},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},eq:function(t){var e=this.length,i=+t+(0>t?e:0);return this.pushStack(i>=0&&e>i?[this[i]]:[])},end:function(){return this.prevObject||this.constructor()},push:ct,sort:ot.sort,splice:ot.splice},vt.extend=vt.fn.extend=function(){var t,e,i,n,r,s,o=arguments[0]||{},a=1,l=arguments.length,u=!1;for("boolean"==typeof o&&(u=o,o=arguments[a]||{},a++),"object"==typeof o||vt.isFunction(o)||(o={}),a===l&&(o=this,a--);l>a;a++)if(null!=(r=arguments[a]))for(n in r)t=o[n],i=r[n],o!==i&&(u&&i&&(vt.isPlainObject(i)||(e=vt.isArray(i)))?(e?(e=!1,s=t&&vt.isArray(t)?t:[]):s=t&&vt.isPlainObject(t)?t:{},o[n]=vt.extend(u,s,i)):void 0!==i&&(o[n]=i));return o},vt.extend({expando:"jQuery"+(mt+Math.random()).replace(/\D/g,""),isReady:!0,error:function(t){throw new Error(t)},noop:function(){},isFunction:function(t){return"function"===vt.type(t)},isArray:Array.isArray||function(t){return"array"===vt.type(t)},isWindow:function(t){return null!=t&&t==t.window},isNumeric:function(t){var e=t&&t.toString();return!vt.isArray(t)&&e-parseFloat(e)+1>=0},isEmptyObject:function(t){var e;for(e in t)return!1;return!0},isPlainObject:function(t){var e;if(!t||"object"!==vt.type(t)||t.nodeType||vt.isWindow(t))return!1;try{if(t.constructor&&!ft.call(t,"constructor")&&!ft.call(t.constructor.prototype,"isPrototypeOf"))return!1}catch(i){return!1}if(!gt.ownFirst)for(e in t)return ft.call(t,e);for(e in t);return void 0===e||ft.call(t,e)},type:function(t){return null==t?t+"":"object"==typeof t||"function"==typeof t?dt[pt.call(t)]||"object":typeof t},globalEval:function(t){t&&vt.trim(t)&&(i.execScript||function(t){i.eval.call(i,t)})(t)},camelCase:function(t){return t.replace(bt,"ms-").replace(_t,wt)},nodeName:function(t,e){return t.nodeName&&t.nodeName.toLowerCase()===e.toLowerCase()},each:function(t,e){var i,n=0;if(o(t))for(i=t.length;i>n&&e.call(t[n],n,t[n])!==!1;n++);else for(n in t)if(e.call(t[n],n,t[n])===!1)break;return t},trim:function(t){return null==t?"":(t+"").replace(yt,"")},makeArray:function(t,e){var i=e||[];return null!=t&&(o(Object(t))?vt.merge(i,"string"==typeof t?[t]:t):ct.call(i,t)),i},inArray:function(t,e,i){var n;if(e){if(ht)return ht.call(e,t,i);for(n=e.length,i=i?0>i?Math.max(0,n+i):i:0;n>i;i++)if(i in e&&e[i]===t)return i}return-1},merge:function(t,e){for(var i=+e.length,n=0,r=t.length;i>n;)t[r++]=e[n++];if(i!==i)for(;void 0!==e[n];)t[r++]=e[n++];return t.length=r,t},grep:function(t,e,i){for(var n,r=[],s=0,o=t.length,a=!i;o>s;s++)n=!e(t[s],s),n!==a&&r.push(t[s]);return r},map:function(t,e,i){var n,r,s=0,a=[];if(o(t))for(n=t.length;n>s;s++)r=e(t[s],s,i),null!=r&&a.push(r);else for(s in t)r=e(t[s],s,i),null!=r&&a.push(r);return ut.apply([],a)},guid:1,proxy:function(t,e){var i,n,r;return"string"==typeof e&&(r=t[e],e=t,t=r),vt.isFunction(t)?(i=lt.call(arguments,2),n=function(){return t.apply(e||this,i.concat(lt.call(arguments)))},n.guid=t.guid=t.guid||vt.guid++,n):void 0},now:function(){return+new Date},support:gt}),"function"==typeof Symbol&&(vt.fn[Symbol.iterator]=ot[Symbol.iterator]),vt.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "),function(t,e){dt["[object "+e+"]"]=e.toLowerCase()});var xt=/*!
+!function(e,i){"object"==typeof t&&"object"==typeof t.exports?t.exports=e.document?i(e,!0):function(t){if(!t.document)throw new Error("jQuery requires a window with a document");return i(t)}:i(e)}("undefined"!=typeof window?window:this,function(i,s){function o(t){var e=!!t&&"length"in t&&t.length,i=vt.type(t);return"function"===i||vt.isWindow(t)?!1:"array"===i||0===e||"number"==typeof e&&e>0&&e-1 in t}function a(t,e,i){if(vt.isFunction(e))return vt.grep(t,function(t,n){return!!e.call(t,n,t)!==i});if(e.nodeType)return vt.grep(t,function(t){return t===e!==i});if("string"==typeof e){if(Et.test(e))return vt.filter(e,t,i);e=vt.filter(e,t)}return vt.grep(t,function(t){return vt.inArray(t,e)>-1!==i})}function l(t,e){do t=t[e];while(t&&1!==t.nodeType);return t}function u(t){var e={};return vt.each(t.match(Pt)||[],function(t,i){e[i]=!0}),e}function h(){at.addEventListener?(at.removeEventListener("DOMContentLoaded",c),i.removeEventListener("load",c)):(at.detachEvent("onreadystatechange",c),i.detachEvent("onload",c))}function c(){(at.addEventListener||"load"===i.event.type||"complete"===at.readyState)&&(h(),vt.ready())}function d(t,e,i){if(void 0===i&&1===t.nodeType){var n="data-"+e.replace(It,"-$1").toLowerCase();if(i=t.getAttribute(n),"string"==typeof i){try{i="true"===i?!0:"false"===i?!1:"null"===i?null:+i+""===i?+i:Ht.test(i)?vt.parseJSON(i):i}catch(r){}vt.data(t,e,i)}else i=void 0}return i}function p(t){var e;for(e in t)if(("data"!==e||!vt.isEmptyObject(t[e]))&&"toJSON"!==e)return!1;return!0}function f(t,e,i,n){if(Lt(t)){var r,s,o=vt.expando,a=t.nodeType,l=a?vt.cache:t,u=a?t[o]:t[o]&&o;if(u&&l[u]&&(n||l[u].data)||void 0!==i||"string"!=typeof e)return u||(u=a?t[o]=ot.pop()||vt.guid++:o),l[u]||(l[u]=a?{}:{toJSON:vt.noop}),("object"==typeof e||"function"==typeof e)&&(n?l[u]=vt.extend(l[u],e):l[u].data=vt.extend(l[u].data,e)),s=l[u],n||(s.data||(s.data={}),s=s.data),void 0!==i&&(s[vt.camelCase(e)]=i),"string"==typeof e?(r=s[e],null==r&&(r=s[vt.camelCase(e)])):r=s,r}}function g(t,e,i){if(Lt(t)){var n,r,s=t.nodeType,o=s?vt.cache:t,a=s?t[vt.expando]:vt.expando;if(o[a]){if(e&&(n=i?o[a]:o[a].data)){vt.isArray(e)?e=e.concat(vt.map(e,vt.camelCase)):e in n?e=[e]:(e=vt.camelCase(e),e=e in n?[e]:e.split(" ")),r=e.length;for(;r--;)delete n[e[r]];if(i?!p(n):!vt.isEmptyObject(n))return}(i||(delete o[a].data,p(o[a])))&&(s?vt.cleanData([t],!0):gt.deleteExpando||o!=o.window?delete o[a]:o[a]=void 0)}}}function m(t,e,i,n){var r,s=1,o=20,a=n?function(){return n.cur()}:function(){return vt.css(t,e,"")},l=a(),u=i&&i[3]||(vt.cssNumber[e]?"":"px"),h=(vt.cssNumber[e]||"px"!==u&&+l)&&Ft.exec(vt.css(t,e));if(h&&h[3]!==u){u=u||h[3],i=i||[],h=+l||1;do s=s||".5",h/=s,vt.style(t,e,h+u);while(s!==(s=a()/l)&&1!==s&&--o)}return i&&(h=+h||+l||0,r=i[1]?h+(i[1]+1)*i[2]:+i[2],n&&(n.unit=u,n.start=h,n.end=r)),r}function v(t){var e=Xt.split("|"),i=t.createDocumentFragment();if(i.createElement)for(;e.length;)i.createElement(e.pop());return i}function y(t,e){var i,n,r=0,s="undefined"!=typeof t.getElementsByTagName?t.getElementsByTagName(e||"*"):"undefined"!=typeof t.querySelectorAll?t.querySelectorAll(e||"*"):void 0;if(!s)for(s=[],i=t.childNodes||t;null!=(n=i[r]);r++)!e||vt.nodeName(n,e)?s.push(n):vt.merge(s,y(n,e));return void 0===e||e&&vt.nodeName(t,e)?vt.merge([t],s):s}function b(t,e){for(var i,n=0;null!=(i=t[n]);n++)vt._data(i,"globalEval",!e||vt._data(e[n],"globalEval"))}function w(t){Bt.test(t.type)&&(t.defaultChecked=t.checked)}function _(t,e,i,n,r){for(var s,o,a,l,u,h,c,d=t.length,p=v(e),f=[],g=0;d>g;g++)if(o=t[g],o||0===o)if("object"===vt.type(o))vt.merge(f,o.nodeType?[o]:o);else if(Jt.test(o)){for(l=l||p.appendChild(e.createElement("div")),u=(Ut.exec(o)||["",""])[1].toLowerCase(),c=Yt[u]||Yt._default,l.innerHTML=c[1]+vt.htmlPrefilter(o)+c[2],s=c[0];s--;)l=l.lastChild;if(!gt.leadingWhitespace&&Gt.test(o)&&f.push(e.createTextNode(Gt.exec(o)[0])),!gt.tbody)for(o="table"!==u||Qt.test(o)?"
diff --git a/lib/galaxy/webapps/galaxy/controllers/dataset.py b/lib/galaxy/webapps/galaxy/controllers/dataset.py
index c74da531b6f..97033c4be10 100644
--- a/lib/galaxy/webapps/galaxy/controllers/dataset.py
+++ b/lib/galaxy/webapps/galaxy/controllers/dataset.py
@@ -322,8 +322,8 @@ class DatasetInterface( BaseUIController, UsesAnnotations, UsesItemRatings, Uses
continue
optional = params.get("is_" + name, None)
other = params.get("or_" + name, None)
- if optional and optional == 'true':
- # optional element... == 'true' actually means it is NOT checked (and therefore omitted)
+ if optional and optional == '__NOTHING__':
+ # optional element... == '__NOTHING__' actually means it is NOT checked (and therefore omitted)
setattr(data.metadata, name, None)
else:
if other:
diff --git a/lib/galaxy/webapps/galaxy/controllers/library_common.py b/lib/galaxy/webapps/galaxy/controllers/library_common.py
index 8368cbd3cd6..680bb46e823 100644
--- a/lib/galaxy/webapps/galaxy/controllers/library_common.py
+++ b/lib/galaxy/webapps/galaxy/controllers/library_common.py
@@ -521,8 +521,8 @@ class LibraryCommon( BaseUIController, UsesFormDefinitionsMixin, UsesExtendedMet
if spec.get("readonly"):
continue
optional = kwd.get( "is_" + name, None )
- if optional and optional == 'true':
- # optional element... == 'true' actually means it is NOT checked (and therefore ommitted)
+ if optional and optional == '__NOTHING__':
+ # optional element... == '__NOTHING__' actually means it is NOT checked (and therefore ommitted)
setattr( ldda.metadata, name, None )
else:
setattr( ldda.metadata, name, spec.unwrap( kwd.get( name, None ) ) )